RustQ.Diagnostic (rustq v0.11.1)

Copy Markdown View Source

Structured RustQ diagnostic data for lowering/rendering failures.

Summary

Functions

Builds structured diagnostic data for extension and tooling errors.

Types

t()

@type t() :: %RustQ.Diagnostic{
  details: map(),
  kind: atom(),
  message: String.t(),
  node: Macro.t() | nil,
  phase: atom(),
  snippet: String.t() | nil,
  suggestion: String.t() | nil
}

Functions

new(phase, kind, node, message, opts \\ [])

@spec new(atom(), atom(), Macro.t() | nil, String.t(), keyword()) :: t()

Builds structured diagnostic data for extension and tooling errors.