Generates Rustler keyword/options structs, decoders, and option helper functions.
Summary
Functions
Builds an options struct and its decoder from structural field metadata.
Builds reusable keyword/options decoding helpers.
Functions
@spec decoder( atom() | String.t(), keyword() ) :: [RustQ.Rust.AST.Struct.t() | RustQ.Rust.AST.Function.t()]
Builds an options struct and its decoder from structural field metadata.
@spec helpers(keyword()) :: [RustQ.Rust.AST.Function.t()]
Builds reusable keyword/options decoding helpers.