RustQ.Rustler.TaggedEnum (rustq v0.11.1)

Copy Markdown View Source

Generates Rust enums decoded from tagged Elixir struct or map terms.

Summary

Functions

Builds the enum and its Rustler decoder and encoder implementations.

Functions

items(name, opts)

@spec items(
  atom() | String.t(),
  keyword()
) :: [RustQ.Rust.AST.Enum.t() | RustQ.Rust.AST.Impl.t()]

Builds the enum and its Rustler decoder and encoder implementations.